FinancialPeriodDetails - agents API reference (0.0.10)

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# FinancialPeriodDetails

class inmydata.CalendarAssistant.FinancialPeriodDetails(year: int, month: int, week: int, quarter: int)

  Bases: `object`

  A structure class for passing financial periods. It contains the year, month, week, and quarter for a given date.

  year

    The financial year.

    Type:

      int

  month

    The financial month (1-12).

    Type:

      int

  week

    The financial week (1-53).

    Type:

      int

  quarter

    The financial quarter (1-4).

    Type:

      int